# CONTRIBUTING
Thank you for your interest in contributing to this project! We welcome contributions from everyone. Please follow the guidelines below to ensure a smooth process.

## Git
If you are not familiar with git, please read the [git_std_rule](source/docs/Rules/git_std_rule.md) file. 
Alternative, you can ask Claude Code to help your commit, just like: `help me commit my change to git`,
although it is powerful, please concentrate on its message and what it do, it may be a mistake from it.

Or, you can add the file manually and ask it to generate the commit message for you automatically, like:
```bash
# In Claude Code, the sign ! means this is a terminal command
!git add <the_files_you_want_to_commit>
> help me commit the message to github

# After review the commit, you can push the commit
git push
```

## Legal Notice

By contributing to this project, you agree to the terms of the [Contributor License Agreement](docs/Rights/CLA.md). If you do not have the rights to submit the code, please do not contribute.
